@@ -64,6 +64,7 @@ TEMPLATES = {
             pretty = true
             show_error_codes = true
             show_error_context = true
+            strict = true
             warn_no_return = true
             warn_redundant_casts = true
             warn_unreachable = true
@@ -85,6 +86,10 @@ TEMPLATES = {
         ".flake8": """
             [flake8]
             max-line-length = 120
+            # Black can yield formatted code that triggers these Flake8 warnings.
+            ignore=
+                W503, # line break before binary operator
+                W504, # line break after binary operator
         """,
         ".gitignore": """
             /.vscode
